Trust is a read-only hierarchical database with data stored in JSON format and served locally or through REST.

The `detailed documentation of Trust database <https://trust.pelicandd.com/>`_ is available on the official website. It also contains an online tool which let you test different queries and parameters.

Contributing
------------

The `source code <https://source.pelicandd.com/infrastructure/trust/>`_ is also available. The package is distributed under `MIT License <https://opensource.org/licenses/MIT>`_.

If you want to have SVN access to the official repository in order to contribute to the project, contact me at `arseni.mourzenko@pelicandd.com <mailto:arseni.mourzenko@pelicandd.com>`_. If you find it more convinient to clone the source to GitHub, you can do that too.
